@@ -17,12 +17,18 @@ class Action(object):
         self.rightv=self.fv+0.5*self.W*self.rv
         self.rightv=(500/0.2)*self.rightv
 
+
 class Input(object):
     def __init__(self):
         self.prox_horizontal=[0.0 for i in range(7)]
         self.prox_ground=ProxGround()
         self.temperature=0.0
         self.accelerometer=[0.0,0.0,0.0]
+        self.button_center=0
+        self.button_left=0
+        self.button_right=0
+        self.button_forward=0
+        self.button_backward=0
 
 class ProxGround(object):
     def __init__(self,delta=[0.0,0.0],reflected=[0.0,0.0],ambiant=[0.0,0.0]):
